Skip to contents

Probes the API for available years for a specific indicator and level, then allows the user to select one or more years.

Usage

select_years(variable, level)

Arguments

variable

Indicator ID.

level

Spatial level ID.

Value

Character vector of years.