Checks the INKAR API for new indicators not present in the local
indicators dataset. The check is informational only; reinstall
the package to permanently add new indicators to local metadata.
Usage
update_indicators(lang = c("de", "en"))Checks the INKAR API for new indicators not present in the local
indicators dataset. The check is informational only; reinstall
the package to permanently add new indicators to local metadata.
update_indicators(lang = c("de", "en"))